@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2014,2016 Aurimas Cernius
+ * Copyright (C) 2011-2014,2016-2017 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -393,9 +393,7 @@ void RemoteControl::on_note_saved(const NoteBase::Ptr & note)
 
 MainWindow & RemoteControl::present_note(const NoteBase::Ptr & note)
 {
-  MainWindow & window = IGnote::obj().get_window_for_note();
-  MainWindow::present_in(window, static_pointer_cast<Note>(note));
-  return window;
+  return *MainWindow::present_default(static_pointer_cast<Note>(note));
 }
 
 
