@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2016 Aurimas Cernius
+ * Copyright (C) 2010-2017 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -118,6 +118,8 @@ namespace gnote {
     GnoteCommandLine passed_cmd_line;
     GnoteCommandLine &cmdline = m_manager ? passed_cmd_line : cmd_line;
     cmdline.parse(argc, argv);
+    m_is_background = cmdline.background();
+    m_is_shell_search = cmd_line.shell_search();
     if(!m_manager) {
       common_init();
       register_object();
@@ -125,7 +127,7 @@ namespace gnote {
     else if(cmdline.needs_execute()) {
       cmdline.execute();
     }
-    else if(!cmdline.background() && !cmdline.shell_search()) {
+    else if(!(cmdline.background() || cmdline.shell_search())) {
       new_main_window().present();
     }
 
@@ -152,7 +154,6 @@ namespace gnote {
 
   void Gnote::end_main(bool bus_acquired, bool name_acquired)
   {
-    m_is_shell_search = cmd_line.shell_search();
     if(cmd_line.needs_execute()) {
       cmd_line.execute();
     }
@@ -169,7 +170,7 @@ namespace gnote {
           Glib::RefPtr<RemoteControlClient> remote;
           try {
             remote = RemoteControlProxy::get_instance();
-            DBG_ASSERT(remote, "remote is NULL, something is wrong");
+            DBG_ASSERT(bool(remote), "remote is NULL, something is wrong");
             if(remote) {
               remote->DisplaySearch();
             }
@@ -300,7 +301,7 @@ namespace gnote {
     about.set_program_name("Gnote");
     about.set_version(VERSION);
     about.set_logo(IconManager::obj().get_icon(IconManager::GNOTE, 48));
-    about.set_copyright(_("Copyright \xc2\xa9 2010-2016 Aurimas Cernius\n"
+    about.set_copyright(_("Copyright \xc2\xa9 2010-2017 Aurimas Cernius\n"
                           "Copyright \xc2\xa9 2009-2011 Debarshi Ray\n"
                           "Copyright \xc2\xa9 2009 Hubert Figuiere\n"
                           "Copyright \xc2\xa9 2004-2009 the Tomboy original authors."));
