@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2015 Aurimas Cernius
+ * Copyright (C) 2010-2015,2017 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -476,7 +476,7 @@ notebooks::Notebook::Ptr SearchNotesWidget::get_selected_notebook() const
 void SearchNotesWidget::select_all_notes_notebook()
 {
   Glib::RefPtr<Gtk::TreeModel> model = m_notebooksTree->get_model();
-  DBG_ASSERT(model, "model is NULL");
+  DBG_ASSERT(bool(model), "model is NULL");
   if(!model) {
     return;
   }
